@@ -408,7 +408,7 @@ Hware_Hl2_EepromMACUse = 'Ignore'
 ## hermes_TxLNA_dB			LNA during Tx dB, integer
 # During transmit the low noise Rx amplifier gain changes to this value (in dB) if the hardware supports it.
 # Changes are immediate (no need to restart).
-hermes_TxLNA_dB = 21
+hermes_TxLNA_dB = -12
 
 ## hermes_tx_buffer_latency		Tx buffer msec, integer
 # This is the latency of the transmit buffer in milliseconds.
@@ -464,6 +464,17 @@ hermes_reset_on_disconnect = False
 hermes_bias_adjust = False
 #hermes_bias_adjust = True
 
+## hermes_iob_rxin			IO board Rx input, text choice
+# This controls the usage of the Rx input J9 and the Pure Signal input J10 on the N2ADR IO board. This option
+# has no effect if the IO board is not installed.
+# The first option disables the Rx input at J9 and the HL2 operates as usual. The Pure Signal input at J10 is available.
+# The second option connects the HL2 receive input to J9. J10 is not available.
+# The third option connects the HL2 receive input to J9 on Rx and to J10 on Tx.
+# Changes are immediate (no need to restart).
+hermes_iob_rxin = 'J10 available'
+#hermes_iob_rxin = 'HL2 Rx to J9'
+#hermes_iob_rxin = 'Use J9 and J10'
+
 
 # These are known power meter calibration tables. This table is not present in the JSON settings file.
 power_meter_std_calibrations = {}
@@ -1385,7 +1396,7 @@ hot_key_ptt2 = wx.ACCEL_NORMAL
 ## hot_key_ptt_toggle	PTT key toggle, boolean
 # Set to True if you want PTT to remain on when you release the key.  A second key press will
 # then release PTT.  This is toggle mode.  If False, you must keep pressing the key, and releasing
-# it will release PTT. This also applies to the MIDI PTT control.
+# it will release PTT.
 # Changes are immediate (no need to restart).
 hot_key_ptt_toggle = False
 #hot_key_ptt_toggle = True
@@ -1410,6 +1421,13 @@ midi_cwkey_note = -1
 #midi_cwkey_note = 60
 #midi_cwkey_note = 69
 
+## midi_ptt_toggle	Midi PTT toggle, boolean
+# Set to True if you want PTT to remain on when you release the Midi PTT button.  A second button press will
+# then release PTT.  This is toggle mode.  If False, you must keep pressing the button, and releasing
+# it will release PTT.
+# Changes are immediate (no need to restart).
+midi_ptt_toggle = False
+#midi_ptt_toggle = True
 
 
 
